@@ -1,9 +1,10 @@
 import multiprocessing
 import os
 import shutil
+import sys
 from multiprocessing.pool import ThreadPool
 from os.path import isfile, isdir, exists
-from typing import Tuple, Sequence, Any, Union
+from typing import Tuple, Sequence, Any, Union, Optional
 
 import dask
 import numpy
@@ -15,18 +16,9 @@ from zarr import open_group, convenience, CopyError, Blosc, Group
 from dexp.datasets.base_dataset import BaseDataset
 # Configure multithreading for Dask:
 from dexp.processing.backends.backend import Backend
+from dexp.utils.config_dask import config_dask
 
-_cpu_count = multiprocessing.cpu_count() // 2
-# aprint(f"Number of cores on system: {_cpu_count}")
-_nb_threads = max(1, _cpu_count)
-dask.config.set(scheduler='threads')
-dask.config.set(pool=ThreadPool(_nb_threads))
-
-# Configure multithreading for Blosc:
-blosc.set_nthreads(_nb_threads)
-
-
-# aprint(f"Number of threads used by BLOSC: {blosc.get_nthreads()}")
+config_dask()
 
 
 class ZDataset(BaseDataset):
@@ -192,7 +184,7 @@ class ZDataset(BaseDataset):
     def dtype(self, channel: str):
         return self.get_array(channel).dtype
 
-    def info(self, channel: str = None) -> str:
+    def info(self, channel: str = None, cli_history: bool = True) -> str:
         info_str = ''
         if channel:
             info_str += f"Channel: '{channel}', nb time points: {self.shape(channel)[0]}, shape: {self.shape(channel)[1:]}"
@@ -215,6 +207,15 @@ class ZDataset(BaseDataset):
             info_str += str(array.info)
             info_str += '\n'
 
+        if cli_history:
+            key = 'cli_history'
+            if key in self._root_group.attrs:
+                info_str += "\nCommand line history:\n/\n"
+                commands_list = self._root_group.attrs[key]
+                for command in commands_list[:-1]:
+                    info_str += " ├──" + command + "\n"
+                info_str += " └──" + commands_list[-1] + "\n"
+
         return info_str
 
     def get_metadata(self):
@@ -224,6 +225,20 @@ class ZDataset(BaseDataset):
             attrs[name] = self._root_group.attrs[name]
         return attrs
 
+    def set_cli_history(self, parent: Optional['ZDataset']):
+        key = 'cli_history'
+        cli_history = []
+        if parent is not None:
+            parent_metadata = parent.get_metadata()
+            cli_history = parent_metadata.get(key, [])
+
+        if key in self._root_group.attrs:
+            cli_history += self._root_group.attrs[key]
+
+        new_command = os.path.basename(sys.argv[0]) + ' ' + ' '.join(sys.argv[1:])
+        cli_history.append(new_command)
+        self._root_group.attrs[key] = cli_history
+
     def get_array(self, channel: str, per_z_slice: bool = False, wrap_with_dask: bool = False):
         array = self._arrays[channel]
         return dask.array.from_array(array, chunks=array.chunks) if wrap_with_dask else array
